@@ -351,7 +351,7 @@ void SipClient::incomingMessage( int socketfd )
 	unsigned int contentLength = 0;
 
 	// Receive the message
-	printf( "SipClient: Receiving message...\n" );
+	printf( tr("SipClient: Receiving message...") + "\n" );
 	for(;;) {
 		bytesread = read( socketfd, inputbuf, 8000 - 1 );
 		StunMsgHdr* hdr = reinterpret_cast<StunMsgHdr*>( inputbuf );
@@ -646,7 +646,7 @@ void SipClient::parseMessage( QString fullmessage )
 						} else {
 							printf( "SipClient: Dropping ACK/CANCEL which deserved a 481\n" );
 						}
-					delete curmessage;
+						delete curmessage;
 						return;
 					}
 				}
@@ -764,7 +764,7 @@ void SipClient::parseMessage( QString fullmessage )
 	}
 }
 
-bool SipClient::sendRequest( SipMessage *msg, bool contact, const SipUri &regProxy )
+bool SipClient::sendRequest( SipMessage *msg, bool contact, const SipUri &regProxy, const QString &branch )
 {
 	if( regProxy != SipUri::null ) {
 		sipProxy = regProxy;
@@ -788,6 +788,13 @@ bool SipClient::sendRequest( SipMessage *msg, bool contact, const SipUri &regPro
 	} else {
 		regvia.setPortNumber( listener.getPortNumber() );
 	}
+
+	if( branch != QString::null ) {
+		regvia.setBranchParam( branch );
+	} else {
+		regvia.generateBranchParam();
+	}
+
 	msg->getViaList().insertTopmostVia( regvia );
 
 	// Calculate content length
@@ -938,7 +945,7 @@ bool SipClient::sendRequest( SipMessage *msg, bool contact, const SipUri &regPro
 			s = &listener;
 		} else {
 			s = &sendsocket;
-	}
+		}
 
 		// Choose destination
 		if( useExplicitProxy ) {
@@ -1310,7 +1317,9 @@ void SipClient::sendAck( SipMessage *origmessage )
 	msg->insertHeader( SipHeader::From, origmessage->getHeaderData( SipHeader::From ) );
 	msg->insertHeader( SipHeader::To, origmessage->getHeaderData( SipHeader::To ) );
 	msg->insertHeader( SipHeader::Call_ID, origmessage->getHeaderData( SipHeader::Call_ID ) );
-	sendRequest( msg );
+	// We need the correct branch parameter
+	QString branch = origmessage->getViaList().getBottommostVia().getBranchParam();
+	sendRequest( msg, true, SipUri::null, branch );
 	delete msg;
 }
 
@@ -1336,7 +1345,7 @@ void SipClient::setCallForwardMessage( const QString &newmessage )
 
 const QString SipClient::getUserAgent( void )
 {
-	return "kphone/4.0.3";
+	return "kphone/4.0.5";
 }
 
 void SipClient::setMaxForwards( int newmax )
