@@ -26,7 +26,10 @@ void DspAudioIn::timerTick( void )
 	}
 
 	int bytes = input->readableBytes();
-
+	
+	// Fixed problem with ALSA or the OSS emulation layer
+	bytes=bytes&0xfff0;
+	
 	if( bytes > 0 ) {
 
 		// Read in a buffer
@@ -48,9 +51,9 @@ void DspAudioIn::timerTick( void )
 			udp_failures++;
 			if(udp_failures > 5){
 				broken = true;
-				printf( "DspAudioIn: Broken pipe\n" );
+				printf( QObject::tr("DspAudioIn: Broken pipe") + "\n" );
 			} else {
-				printf( "DspAudioIn: UDP-failure(%d)\n", udp_failures );
+				printf( QObject::tr("DspAudioIn: UDP-failure(%d)") + "\n", udp_failures );
 			}
 		} else {
 			udp_failures = 0;
