@@ -41,25 +41,25 @@ KCallTransfer::KCallTransfer( QWidget *parent, const char *name )
 	QVBoxLayout *vboxl = new QVBoxLayout( this, 5 );
 	vboxl->addWidget( vbox );
 
-	(void) new QLabel( "Transfer to URI:", vbox );
+	(void) new QLabel( tr("Transfer to URI:"), vbox );
 	touri = new QLineEdit( vbox );
 	touri->setMinimumWidth( fontMetrics().maxWidth() * 20 );
 
 	QHBoxLayout *buttonBox;
 	buttonBox = new QHBoxLayout( vboxl, 6 );
-	helpPushButton = new QPushButton( this, "help button" );
-	helpPushButton->setText( "&help..." );
+	helpPushButton = new QPushButton( this, tr("help button") );
+	helpPushButton->setText( tr("&help...") );
 	helpPushButton->setEnabled( FALSE );
 	buttonBox->addWidget( helpPushButton );
 	QSpacerItem *spacer = new QSpacerItem(
 		0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum );
 	buttonBox->addItem( spacer );
-	okPushButton = new QPushButton( this, "ok button" );
-	okPushButton->setText( "OK" );
+	okPushButton = new QPushButton( this, tr("ok button") );
+	okPushButton->setText( tr("OK") );
 	okPushButton->setDefault( TRUE );
 	buttonBox->addWidget( okPushButton );
-	cancelPushButton = new QPushButton( this, "cancel button" );
-	cancelPushButton->setText( "Cancel" );
+	cancelPushButton = new QPushButton( this, tr("cancel button") );
+	cancelPushButton->setText( tr("Cancel") );
 	cancelPushButton->setAccel( Key_Escape );
 	buttonBox->addWidget( cancelPushButton );
 	connect( okPushButton, SIGNAL( clicked() ),
@@ -126,9 +126,9 @@ KCallWidget::KCallWidget( KSipAuthentication *auth, CallAudio *callaudio, SipCal
 	vbox->insertLayout( 0, headergrid );
 
 	// Remote (person we're calling)
-	QLabel *remotelabel = new QLabel( "Remote: ", this );
+	QLabel *remotelabel = new QLabel( tr("Remote: "), this );
 	remotelabel->setFixedWidth(
-		remotelabel->fontMetrics().width( "  Remote:  "  ) );
+		remotelabel->fontMetrics().width( tr("  Remote:  ")  ) );
 	headergrid->addWidget( remotelabel, 0, 0 );
 	remote = new QComboBox( true, this );
 	remote->setAutoCompletion( true );
@@ -158,39 +158,39 @@ KCallWidget::KCallWidget( KSipAuthentication *auth, CallAudio *callaudio, SipCal
 	QHBox *statline = new QHBox( this );
 	statline->setSpacing( 5 );
 	vbox->insertWidget( 1, statline );
-	QLabel *statlabel = new QLabel( "Status: ", statline );
+	QLabel *statlabel = new QLabel( tr("Status: "), statline );
 	statlabel->setFixedWidth( remotelabel->width() );
 	curstat = new QLabel( statline );
-	QLabel *astatlabel = new QLabel( "Audio: ", statline );
+	QLabel *astatlabel = new QLabel( tr("Audio: "), statline );
 	astatlabel->setFixedWidth( remotelabel->width() );
 	curaudiostat = new QLabel( statline );
 	QGrid *buttonbox = new QGrid(2, this );
 	buttonbox->setSpacing( 5 );
 	vbox->insertWidget( 2, buttonbox );
-	dial = new QPushButton( "Dial", buttonbox );
+	dial = new QPushButton( tr("Dial"), buttonbox );
 	QIconSet icon1;
 	icon1.setPixmap(SHARE_DIR "/icons/dial.png", QIconSet::Automatic );
 	dial->setIconSet( icon1 );
 	connect( dial, SIGNAL( clicked() ), this, SLOT( dialClicked() ) );
 	dial->setEnabled( true );
 	dial->setFocus();
-	hangup = new QPushButton( "Hangup", buttonbox );
+	hangup = new QPushButton( tr("Hangup"), buttonbox );
 	QIconSet icon2;
 	icon2.setPixmap(SHARE_DIR "/icons/hangup.png", QIconSet::Automatic );
 	hangup->setIconSet( icon2 );
 	connect( hangup, SIGNAL( clicked() ), this, SLOT( hangupCall() ) );
 	hangup->setEnabled( false );
-	holdbutton = new QPushButton( "Hold", buttonbox );
+	holdbutton = new QPushButton( tr("Hold"), buttonbox );
 	connect( holdbutton, SIGNAL( clicked() ), this, SLOT( holdCall() ) );
-	transferbutton = new QPushButton( "Transfer", buttonbox );
+	transferbutton = new QPushButton( tr("Transfer"), buttonbox );
 	connect( transferbutton, SIGNAL( clicked() ),
 		this, SLOT( showTransferDialog() ) );
-	morebutton = new QPushButton( "DTMF", buttonbox );
+	morebutton = new QPushButton( tr("DTMF"), buttonbox );
 	morebutton->setToggleButton(true);
 	morebutton->setOn( false );
 	connect( morebutton, SIGNAL( toggled(bool) ),
 		this, SLOT( showExtension(bool)));
-	hidebutton = new QPushButton( "Hide", buttonbox );
+	hidebutton = new QPushButton( tr("Hide"), buttonbox );
 	connect( hidebutton, SIGNAL( clicked() ), this, SLOT( hideCall() ) );
 	QDateTime dt;
 	int year,month,day,hour,min,sec;
@@ -335,8 +335,8 @@ void KCallWidget::switchCall( SipCall *newcall )
 	printf( "KCallWidget: Switching calls...\n" );
 	call = newcall;
 	audio->setBodyMask( call->getSdpMessageMask() );
-	dial->setText( "Dial" );
-	hangup->setText( "Hangup" );
+	dial->setText( tr("Dial") );
+	hangup->setText( tr("Hangup") );
 	if( member ) disconnect( member, 0, this, 0 );
 	member = call->getMemberList().toFirst();
 	if( member ) {
@@ -351,16 +351,16 @@ void KCallWidget::switchCall( SipCall *newcall )
 		curstat->setText( member->getLocalStatusDescription() );
 		connect( member, SIGNAL( statusUpdated( SipCallMember * ) ),
 			this, SLOT( callMemberStatusUpdated() ) );
-		setCaption( getUserPrefix() + QString( "Call: " ) + call->getCallId() );
-		if( call->getSubject() == "Incoming call" ) {
+		setCaption( getUserPrefix() + QString( tr("Call: ") ) + call->getCallId() );
+		if( call->getSubject() == tr("Incoming call") ) {
 			if( call->getCallType() == SipCall::videoCall ) {
 				setCaption( getUserPrefix() +
-					QString( "Incoming Video Call: " ) + call->getCallId() );
+					QString( tr("Incoming Video Call: ") ) + call->getCallId() );
 				holdbutton->setEnabled( false );
 				transferbutton->setEnabled( false );
 			} else {
 				setCaption( getUserPrefix() +
-					QString( "Incoming Call: " ) + call->getCallId() );
+					QString( tr("Incoming Call: ") ) + call->getCallId() );
 				holdbutton->setEnabled( true );
 				transferbutton->setEnabled( true );
 			}
@@ -389,8 +389,8 @@ void KCallWidget::switchCall( SipCall *newcall )
 			hangup->setEnabled( true );
 			curstate = Calling;
 		} else if( member->getState() == SipCallMember::state_RequestingInvite ) {
-			dial->setText( "Accept" );
-			hangup->setText( "Reject" );
+			dial->setText( tr("Accept") );
+			hangup->setText( tr("Reject") );
 			hidebutton->setEnabled( false );
 			dial->setEnabled( true );
 			hangup->setEnabled( true );
@@ -405,12 +405,12 @@ void KCallWidget::switchCall( SipCall *newcall )
 		curstat->setText( QString::null );
 		if( call->getCallType() == SipCall::videoCall ) {
 			setCaption( getUserPrefix() +
-				QString( "Outgoing Video Call: " ) + call->getCallId() );
+				QString( tr("Outgoing Video Call: ") ) + call->getCallId() );
 			holdbutton->setEnabled( false );
 			transferbutton->setEnabled( false );
 		} else {
 			setCaption( getUserPrefix() +
-				QString( "Outgoing Call: " ) + call->getCallId() );
+				QString( tr("Outgoing Call: ") ) + call->getCallId() );
 			holdbutton->setEnabled( true );
 			transferbutton->setEnabled( true );
 		}
@@ -438,15 +438,15 @@ void KCallWidget::dialClicked( void )
 		return;
 	}
 	if( remote->currentText().length() == 0 ) {
-		QMessageBox::critical( this, "Error: No Destination",
-			"You must specify someone to call." );
+		QMessageBox::critical( this, tr("Error: No Destination"),
+			tr("You must specify someone to call.") );
 		return;
 	}
 	if( !audio->isAudioOn() ) {
-		audio_fd = ::open( "/dev/dsp", O_WRONLY | O_NONBLOCK );
+		audio_fd = ::open( audio->getOSSFilename(), O_WRONLY | O_NONBLOCK );
 		if( audio_fd == -1 ) {
-			QMessageBox::information( this, "Dial",
-				"Close any program which might be using soundcard \nand then retry dial." );
+			QMessageBox::information( this, tr("Dial"),
+				tr("Close any program which might be using soundcard \nand then retry dial.") );
 			return;
 		} else {
 			::close( audio_fd );
@@ -511,10 +511,10 @@ void KCallWidget::callMemberStatusUpdated( void )
 	SdpMessage sdpm;
 	SdpMessage rsdp;
 	if( member->getState() == SipCallMember::state_Disconnected ) {
-		if( member->getLocalStatusDescription().left( 12 ) == "Call Failed:" ) {
-			curstat->setText( "Call Failed" );
+		if( member->getLocalStatusDescription().left( 2 ) == "!!" ) {
+			curstat->setText( tr("Call Failed") );
 			QMessageBox::critical( this, "KPhone",
-				member->getLocalStatusDescription() );
+				member->getLocalStatusDescription().remove(0,2) );
 			setHide();
 		} else {
 			curstat->setText( member->getLocalStatusDescription() );
@@ -525,6 +525,7 @@ void KCallWidget::callMemberStatusUpdated( void )
 		handleRedirect();
 	} else if( member->getState() == SipCallMember::state_Refer ) {
 		curstat->setText( member->getLocalStatusDescription() );
+		member->setState( SipCallMember::state_Refer_handling );
 		handleRefer();
 	} else if( member->getState() == SipCallMember::state_Connected ) {
 		curstat->setText( member->getLocalStatusDescription() );
@@ -581,12 +582,12 @@ void KCallWidget::holdCall( void )
 {
 	if( audio->getCurrentCall() == call ) {
 		audio->toggleOnHold();
-		holdbutton->setText( "Unhold" );
+		holdbutton->setText( tr("Unhold") );
 	} else if( member ) {
 		audio->setCurrentCall( call );
 		audio->attachToCallMember( member );
 		audio->toggleOnHold();
-		holdbutton->setText( "Hold" );
+		holdbutton->setText( tr("Hold") );
 	}
 }
 
@@ -597,9 +598,9 @@ void KCallWidget::handleRedirect( void )
 	SipUriList urilist = member->getRedirectList();
 	while ( urilist.getListLength() > 0 ) {
 		SipUri redirto = urilist.getPriorContact();
-		QMessageBox mb( "Redirect",
-			"Call redirected to: \n" + redirto.reqUri() + "\n\n" +
-			"Do you want to proceed ? ",
+		QMessageBox mb( tr("Redirect"),
+			tr("Call redirected to: ") + "\n" + redirto.reqUri() + "\n\n" +
+			tr("Do you want to proceed ? "),
 			QMessageBox::Information,
 			QMessageBox::Yes | QMessageBox::Default,
 			QMessageBox::No,
@@ -632,9 +633,9 @@ void KCallWidget::handleRefer( void )
 	if( audio->getCurrentCall() == call ) {
 		audio->detachFromCall();
 	}
-	QMessageBox mb( "Redirect",
-		"Call redirected to: \n" + redirto.reqUri() + "\n\n" +
-		"Do you want to proceed ? ",
+	QMessageBox mb( tr("Redirect"),
+		tr("Call redirected to: ") + "\n" + redirto.reqUri() + "\n\n" +
+		tr("Do you want to proceed ? "),
 		QMessageBox::Information,
 		QMessageBox::Yes | QMessageBox::Default,
 		QMessageBox::No,
@@ -666,11 +667,11 @@ void KCallWidget::updateAudioStatus( void )
 {
 	if( audio->getCurrentCall() == call ) {
 		if( audio->isRemoteHold() )
-			curaudiostat->setText( "Attached [holding]" );
+			curaudiostat->setText( tr("Attached [holding]") );
 		else
-			curaudiostat->setText( "Attached [active]" );
+			curaudiostat->setText( tr("Attached [active]") );
 	} else {
-		curaudiostat->setText( "Unattached" );
+		curaudiostat->setText( tr("Unattached") );
 	}
 }
 
@@ -815,7 +816,7 @@ void KCallWidget::ringTimeout( void )
 	if( isRingingTone ) {
 		if( ringCount < 5 ) {
 			ringCount++;
-			audio_fd = ::open( "/dev/dsp", O_WRONLY | O_NONBLOCK );
+			audio_fd = ::open( audio->getOSSFilename(), O_WRONLY | O_NONBLOCK );
 			if( audio_fd == -1 ) {
 				printf( "ERROR: %s\n", "Open Failed" );
 				return;
@@ -881,10 +882,10 @@ void KCallWidget::acceptCallTimeout( void )
 	if( !audio->isAudioOn() ) {
 		if( isRingingTone ) {
 		}
-		audio_fd = ::open( "/dev/dsp", O_WRONLY | O_NONBLOCK );
+		audio_fd = ::open( audio->getOSSFilename(), O_WRONLY | O_NONBLOCK );
 		if( audio_fd == -1 ) {
-			QMessageBox::information( this, "Accept Call",
-				"Close any program which might be using soundcard \nand then retry accepting call." );
+			QMessageBox::information( this, tr("Accept Call"),
+				tr("Close any program which might be using soundcard \nand then retry accepting call.") );
 			return;
 		} else {
 			::close( audio_fd );
@@ -899,15 +900,15 @@ void KCallWidget::acceptCallTimeout( void )
 			audio->audioOut().message( audio->getRtpCodec(),
 				audio->getVideoRtpCodec(), audio->getBodyMask() ),
 			MimeContentType( "application/sdp" ) );
-		dial->setText( "Dial" );
-		hangup->setText( "Hangup" );
+		dial->setText( tr("Dial") );
+		hangup->setText( tr("Hangup") );
 		hidebutton->setEnabled( false );
 		dial->setEnabled( false );
 		hangup->setEnabled( true );
 	} else {
 		member->notAcceptableHere();
-		QMessageBox::information( this, "Accept Call",
-			"Accepted codec not found." );
+		QMessageBox::information( this, tr("Accept Call"),
+			tr("Accepted codec not found.") );
 	}
 }
 
@@ -937,15 +938,15 @@ KInstantMessageWidget::KInstantMessageWidget( KSipAuthentication *auth,
 {
 	sipauthentication = auth;
 	phoneBook = 0;
-	setCaption( getUserPrefix() + " Message - KPhone" );
+	setCaption( getUserPrefix() + tr(" Message - KPhone") );
 	QVBoxLayout *vbox = new QVBoxLayout( this );
 	vbox->setMargin( 3 );
 	vbox->setSpacing( 3 );
 	QGridLayout *headergrid = new QGridLayout( 6, 3 );
 	headergrid->setSpacing( 3 );
 	vbox->insertLayout( 0, headergrid );
-	QLabel *remotelabel = new QLabel( "Remote: ", this );
-	remotelabel->setFixedWidth( remotelabel->fontMetrics().width( "  Remote:  "  ) );
+	QLabel *remotelabel = new QLabel( tr("Remote: "), this );
+	remotelabel->setFixedWidth( remotelabel->fontMetrics().width( tr("  Remote:  ")  ) );
 	headergrid->addWidget( remotelabel, 0, 0 );
 	remote = new QComboBox( true, this );
 	remote->setAutoCompletion( true );
@@ -958,12 +959,12 @@ KInstantMessageWidget::KInstantMessageWidget( KSipAuthentication *auth,
 	loadUri->setFixedWidth( loadUri->fontMetrics().maxWidth() * 2 );
 	connect( loadUri, SIGNAL( clicked() ), this, SLOT( getUri() ) );
 	headergrid->addWidget( loadUri, 0, 2 );
-	QLabel *slabel = new QLabel( "Status: ", this );
+	QLabel *slabel = new QLabel( tr("Status: "), this );
 	vbox->insertWidget( 1, slabel );
 	status = new QTextEdit( this );
 	status->setReadOnly( true );
 	vbox->insertWidget( 2, status );
-	QLabel *mlabel = new QLabel( "Message: ", this );
+	QLabel *mlabel = new QLabel( tr("Message: "), this );
 	vbox->insertWidget( 3, mlabel );
 	QGridLayout *mgrid = new QGridLayout( 1, 3 );
 	mgrid->setSpacing( 3 );
@@ -971,7 +972,7 @@ KInstantMessageWidget::KInstantMessageWidget( KSipAuthentication *auth,
 	mEdit = new QTextEdit( this );
 	mgrid->addWidget( mEdit, 0,0 );
 	mEdit->setFocus();
-	mbutton = new QPushButton( "Send", this );
+	mbutton = new QPushButton( tr("Send"), this );
 	mbutton->setFixedWidth( mbutton->fontMetrics().maxWidth() * 4 );
 	connect( mbutton, SIGNAL( clicked() ), this, SLOT( mClicked() ) );
 	mgrid->addWidget( mbutton, 0, 2 );
@@ -979,7 +980,7 @@ KInstantMessageWidget::KInstantMessageWidget( KSipAuthentication *auth,
 	buttonbox->setSpacing( 5 );
 	vbox->insertWidget( 5, buttonbox );
 	(void) new QWidget( buttonbox );
-	hidebutton = new QPushButton( "Hide", buttonbox );
+	hidebutton = new QPushButton( tr("Hide"), buttonbox );
 	connect( hidebutton, SIGNAL( clicked() ), this, SLOT( hide() ) );
 	resize( 400, 200 );
 }
@@ -997,7 +998,7 @@ void KInstantMessageWidget::instantMessage( SipMessage *message )
 	SipUri u = SipUri( s );
 	remote->setEditText( u.getUsername() + "@" + u.getHostname() );
 	QString m = message->messageBody();
-	status->setText( status->text() + "\nMessage received from " + remote->currentText() );
+	status->setText( status->text() + "\n" + tr("Message received from ") + remote->currentText() );
 	status->setText( status->text() + " (" + QTime::currentTime().toString().latin1() + ")" );
 	status->setText( status->text() + "\n > " + m );
 	status->scrollToBottom();
@@ -1021,8 +1022,8 @@ void KInstantMessageWidget::setRemote( QString newremote )
 void KInstantMessageWidget::mClicked( void )
 {
 	if( remote->currentText().length() == 0 ) {
-		QMessageBox::critical( this, "Error: No Destination",
-			"You must specify someone to send message." );
+		QMessageBox::critical( this, tr("Error: No Destination"),
+			tr("You must specify someone to send message.") );
 		return;
 	}
 	QString strRemoteUri;
@@ -1051,7 +1052,7 @@ void KInstantMessageWidget::mClicked( void )
 	member = new SipCallMember( imcall, remoteuri );
 	connect( member, SIGNAL( statusUpdated( SipCallMember * ) ),
 		sipauthentication, SLOT( authRequest( SipCallMember * ) ) );
-	status->setText( status->text() + "\nMessage sent to " + remote->currentText() );
+	status->setText( status->text() + "\n" + tr("Message sent to ") + remote->currentText() );
 	status->setText( status->text() + " (" + QTime::currentTime().toString().latin1() + ")" );
 	status->setText( status->text() + "\n > " + mEdit->text() );
 	status->scrollToBottom();
