@@ -79,7 +79,7 @@ KPhoneView::KPhoneView( CallAudio *callaudio, SipClient *c, SipUser *u, QWidget
 	QVBoxLayout *vbox = new QVBoxLayout( this );
 	QGridLayout *headergrid = new QGridLayout( 4, 5 );
 	vbox->insertLayout( 0, headergrid );
-	buttonSipUri = new QPushButton( "Set Identity", this );
+	buttonSipUri = new QPushButton( tr("Set Identity"), this );
 	buttonSipUri->setMinimumWidth( kphoneMinimunWidht );
 	headergrid->addMultiCellWidget( buttonSipUri, 0, 0, 0, 4 );
 	connect( buttonSipUri, SIGNAL( clicked() ),
@@ -108,10 +108,10 @@ KPhoneView::KPhoneView( CallAudio *callaudio, SipClient *c, SipUser *u, QWidget
 	callcount = 1;
 	clist = new ContactsListView( client, this );
 	headergrid->addMultiCellWidget( clist, 3, 3, 0, 4 );
-	clist->addMenuItem( "Send Message", this, SLOT( contactSendMessage() ) );
-	clist->addMenuItem( "Call", this, SLOT( contactCall() ) );
-	clist->addMenuItem( "Video Call", this, SLOT( contactVideoCall() ) );
-	clist->addMenuItem( "Phone Book", this, SLOT( showPhoneBook() ) );
+	clist->addMenuItem( tr("Send Message"), this, SLOT( contactSendMessage() ) );
+	clist->addMenuItem( tr("Call"), this, SLOT( contactCall() ) );
+	clist->addMenuItem( tr("Video Call"), this, SLOT( contactVideoCall() ) );
+	clist->addMenuItem( tr("Phone Book"), this, SLOT( showPhoneBook() ) );
 	connect( clist, SIGNAL( doubleClicked( QListViewItem * ) ),
 		this, SLOT( contactDoubleClicked( QListViewItem * ) ) );
 	connect( client, SIGNAL( callListUpdated() ),
@@ -125,9 +125,15 @@ KPhoneView::KPhoneView( CallAudio *callaudio, SipClient *c, SipUser *u, QWidget
 		this, SLOT( buttonOffOnlineClicked() ) );
 	headergrid->addWidget( buttonOffOnline, 4, 0 );
 	stateComboBox = new QComboBox( TRUE, this, "" );
+	QString online = tr("Online");
+	QString busy = tr("Busy");
+	QString berightback = tr("Be Right Back");
+	QString away = tr("Away");
+	QString onthephone = tr("On The Phone");
+	QString outtolunch = tr("Out To Lunch");
 	static const char* items[] = {
-		"Online", "Busy", "Be Right Back", "Away",
-		"On The Phone", "Out To Lunch", 0 };
+		online, busy,berightback, away,
+		onthephone, outtolunch, 0 };
 	stateComboBox->insertStrList( items );
 	connect( stateComboBox, SIGNAL( activated( const QString & )  ),
 		this, SLOT( buttonUpdateClicked() ) );
@@ -233,7 +239,7 @@ KPhoneView::~KPhoneView( void )
 
 void KPhoneView::incomingInstantMessage( SipMessage *message )
 {
-	printf( "KPhoneView: Incoming Instant Message\n" );
+	printf( tr("KPhoneView: Incoming Instant Message") + "\n" );
 	QString subject;
 	QString remote;
 	KInstantMessageWidget *imwidget;
@@ -286,16 +292,16 @@ void KPhoneView::incomingSubscribe( SipCallMember *member, bool sendSubscribe )
 	}
 	if( !find && !remove_subscribe) {
 		QString uristr = member->getUri().reqUri();
-		QMessageBox mb( getUserPrefix() + "KPhone",
-			"Subscribe message from uri:\n" + uristr +
-			"\n\nDo you want to accept and create a contact ?",
+		QMessageBox mb( getUserPrefix() + tr("KPhone"),
+			tr("Subscribe message from uri:") + "\n" + uristr + "\n\n" +
+			tr("Do you want to accept and create a contact ?"),
 			QMessageBox::Information,
 			QMessageBox::Yes | QMessageBox::Default,
 			QMessageBox::No,
 			QMessageBox::Cancel | QMessageBox::Escape );
-		mb.setButtonText( QMessageBox::Yes, "Accept" );
-		mb.setButtonText( QMessageBox::No, "Reject permanently" );
-		mb.setButtonText( QMessageBox::Cancel, "Reject this time" );
+		mb.setButtonText( QMessageBox::Yes, tr("Accept") );
+		mb.setButtonText( QMessageBox::No, tr("Reject permanently") );
+		mb.setButtonText( QMessageBox::Cancel, tr("Reject this time") );
 		switch( mb.exec() ) {
 			case QMessageBox::Yes:
 				addContactToPhoneBook( member );
@@ -365,7 +371,7 @@ void KPhoneView::incomingCall( SipCall *call, QString body )
 	updateWidgetList();
 	if( call->getSubject() == QString::null ) {
 		call->setSdpMessageMask( body );
-		call->setSubject( "Incoming call" );
+		call->setSubject( tr("Incoming call") );
 		KCallWidget *widget = new KCallWidget( 0, callAudio, call, this );
 		cwList.append( widget );
 		connect( widget, SIGNAL( redirectCall( const SipUri &, const QString & ) ),
@@ -388,8 +394,8 @@ void KPhoneView::hideCallWidget( SipCall *call )
 
 void KPhoneView::contactDoubleClicked( QListViewItem *i )
 {
-	if( !buttonSipUri->text().compare( "Set Identity" ) ){
-		QMessageBox::information( this, "KPhone", "Set First Identity." );
+	if( !buttonSipUri->text().compare( tr("Set Identity") ) ){
+		QMessageBox::information( this, tr("KPhone"), tr("Set First Identity.") );
 		return;
 	}
 	QString subject = ( (ContactsListViewItem *) i )->getCall()->getSubject();
@@ -416,8 +422,8 @@ void KPhoneView::contactSendMessage()
 	if( clist->currentItem() != 0 ) {
 		subject = ((ContactsListViewItem *)clist->currentItem())->getCall()->getSubject();
 	}
-	if( !buttonSipUri->text().compare( "Set Identity" ) ){
-		QMessageBox::information( this, "KPhone", "Set First Identity." );
+	if( !buttonSipUri->text().compare( tr("Set Identity") ) ){
+		QMessageBox::information( this, tr("KPhone"), tr("Set First Identity.") );
 		return;
 	}
 	SipUri uri = user->getUri();
@@ -449,8 +455,8 @@ void KPhoneView::contactCall()
 	if( clist->currentItem() != 0 ) {
 		subject = ((ContactsListViewItem *)clist->currentItem())->getCall()->getSubject();
 	}
-	if( !buttonSipUri->text().compare( "Set Identity" ) ){
-		QMessageBox::information( this, "KPhone", "Set First Identity." );
+	if( !buttonSipUri->text().compare( tr("Set Identity") ) ){
+		QMessageBox::information( this, tr("KPhone"), tr("Set First Identity.") );
 		return;
 	}
 	SipCall *newcall = new SipCall( user, QString::null, SipCall::StandardCall );
@@ -470,8 +476,8 @@ void KPhoneView::contactVideoCall()
 	if( clist->currentItem() != 0 ) {
 		subject = ((ContactsListViewItem *)clist->currentItem())->getCall()->getSubject();
 	}
-	if( !buttonSipUri->text().compare( "Set Identity" ) ){
-		QMessageBox::information( this, "KPhone", "Set First Identity." );
+	if( !buttonSipUri->text().compare( tr("Set Identity") ) ){
+		QMessageBox::information( this, tr("KPhone"), tr("Set First Identity.") );
 		return;
 	}
 	SipCall *newcall = new SipCall( user, QString::null, SipCall::videoCall );
@@ -525,7 +531,7 @@ void KPhoneView::addContactToPhoneBook( SipCallMember *member )
 	QPtrList<IncomingCall> m;
 	QStringList s;
 	PhoneBook *phoneBook = new PhoneBook(
-		file, this, getUserPrefix() + "Phone Book", r, m, s );
+		file, this, getUserPrefix() + tr("Phone Book"), r, m, s );
 	phoneBook->addContact( member );
 	updateContacts( file );
 }
@@ -687,6 +693,7 @@ void KPhoneView::localStatusUpdate( void )
 			}
 		}
 	}
+	emit ( stateChanged() );
 }
 
 void KPhoneView::buttonOffOnlineClicked( void )
@@ -743,27 +750,29 @@ void KPhoneView::stateUpdated( int id )
 			}
 		}
 	}
+	emit( stateChanged() );
+	
 }
 
 QString KPhoneView::stateText( QString text )
 {
-  QString state;
-  if( text == "Online" ) {
+	QString state;
+	if( text == tr("Online") ) {
 		state = "online";
-	} else if( text == "Busy" ) {
+	} else if( text == tr("Busy") ) {
 		state = "busy";
-	} else if( text == "Be Right Back" ) {
+	} else if( text == tr("Be Right Back") ) {
 		state = "berightback";
-	} else if( text == "Away" ) {
+	} else if( text == tr("Away") ) {
 		state = "away";
-	} else if( text == "On The Phone" ) {
+	} else if( text == tr("On The Phone") ) {
 		state = "onthephone";
-	} else if( text == "Out To Lunch" ) {
+	} else if( text == tr("Out To Lunch") ) {
 		state = "outtolunch";
 	} else {
 		state = text;
 	}
-  return state;
+	return state;
 }
 
 
@@ -831,8 +840,8 @@ void KPhoneView::redirectCall( const SipUri &calluri, const QString &subject )
 void KPhoneView::makeNewCall( void )
 {
 	updateWidgetList();
-	if( !buttonSipUri->text().compare( "Set Identity" ) ){
-		QMessageBox::information( this, "KPhone", "Set First Identity." );
+	if( !buttonSipUri->text().compare( tr("Set Identity") ) ){
+		QMessageBox::information( this, tr("KPhone"), tr("Set First Identity.") );
 		return;
 	}
 	SipCall *newcall = new SipCall( user, QString::null, SipCall::StandardCall );
@@ -854,8 +863,8 @@ void KPhoneView::makeNewCall( void )
 void KPhoneView::makeVideoCall( void )
 {
 	updateWidgetList();
-	if( !buttonSipUri->text().compare( "Set Identity" ) ){
-		QMessageBox::information( this, "KPhone", "Set First Identity." );
+	if( !buttonSipUri->text().compare( tr("Set Identity") ) ){
+		QMessageBox::information( this, tr("KPhone"), tr("Set First Identity.") );
 		return;
 	}
 	SipCall *newcall = new SipCall( user, QString::null, SipCall::videoCall );
@@ -966,3 +975,8 @@ void KPhoneView::updateWidgetList( void )
 		}
 	}
 }
+
+bool KPhoneView::getState( void )
+{
+	return isOnline;
+}
